@@ -2,8 +2,6 @@ import numpy
 import xarray
 import matplotlib.pyplot as plt
 
-
-
 class objearth():
     def __init__(self):
         pass
@@ -72,7 +70,8 @@ class objearth():
         else:
             print("Nonetype :",type(self.DataArray))
             
-    def NDVI(self):
+    def NDVI(self,DataArray):
+        self.DataArray = DataArray
         red = xarray.where(self.DataArray.red==-9999,numpy.nan,self.DataArray.red)
         nir = xarray.where(self.DataArray.nir==-9999,numpy.nan,self.DataArray.nir)
         ndvi1 = (nir-red)/(nir+red).to_numpy()
@@ -96,9 +95,4 @@ class objearth():
         Cpixel    = (numpy.isnan(dsnew.to_numpy())).sum()
         Allpixel  = int(self.Dataset.pixel_qa.count())
         Cloudpercent = (Cpixel/Allpixel)*100
-        print("Percent Cloud : %.4f"%Cloudpercent,"%")
-
-
-
-    
-
+        print("Percent Cloud : %.4f"%Cloudpercent,"%")
\ No newline at end of file
